//>>built
define("dojo/nls/dojo_cs",{"dijit/form/nls/validate":{invalidMessage:"Zadan\u00e1 hodnota nen\u00ed platn\u00e1.",missingMessage:"Tato hodnota je vy\u017eadov\u00e1na.",rangeMessage:"Tato hodnota je mimo rozsah.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0bil'.'",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4",perMille:"\u2030",group:"\u00a0",percentFormat:"#,##0\u00a0%","decimalFormat-long":"000 bilion\u016f",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"P\u0159edchoz\u00ed volby",
nextMessage:"Dal\u0161\u00ed volby",_localized:{}},"dijit/nls/loading":{loadingState:"Prob\u00edh\u00e1 na\u010d\u00edt\u00e1n\u00ed...",errorState:"Omlouv\u00e1me se, do\u0161lo k chyb\u011b",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Storno",buttonSave:"Ulo\u017eit",itemClose:"Zav\u0159\u00edt",_localized:{}},"dijit/_editor/nls/commands":{bold:"Tu\u010dn\u00e9",copy:"Kop\u00edrovat",cut:"Vyjmout","delete":"Odstranit",indent:"Odsadit",insertHorizontalRule:"Vodorovn\u00e1 \u010d\u00e1ra",
insertOrderedList:"\u010c\u00edslovan\u00fd seznam",insertUnorderedList:"Seznam s odr\u00e1\u017ekami",italic:"Kurz\u00edva",justifyCenter:"Zarovnat na st\u0159ed",justifyFull:"Do bloku",justifyLeft:"Zarovnat vlevo",justifyRight:"Zarovnat vpravo",outdent:"P\u0159edsadit",paste:"Vlo\u017eit",redo:"Opakovat",removeFormat:"Odebrat form\u00e1t",selectAll:"Vybrat v\u0161e",strikethrough:"P\u0159e\u0161krtnut\u00ed",subscript:"Doln\u00ed index",superscript:"Horn\u00ed index",underline:"Podtr\u017een\u00ed",
undo:"Zp\u011bt",unlink:"Odebrat odkaz",createLink:"Vytvo\u0159it odkaz",toggleDir:"P\u0159epnout sm\u011br",insertImage:"Vlo\u017eit obr\u00e1zek",insertTable:"Vlo\u017eit/upravit tabulku",toggleTableBorder:"P\u0159epnout ohrani\u010den\u00ed tabulky",deleteTable:"Odstranit tabulku",tableProp:"Vlastnost tabulky",htmlToggle:"Zdroj HTML",foreColor:"Barva pop\u0159ed\u00ed",hiliteColor:"Barva pozad\u00ed",plainFormatBlock:"Styl odstavce",formatBlock:"Styl odstavce",fontSize:"Velikost p\u00edsma",fontName:"N\u00e1zev p\u00edsma",
tabIndent:"Odsazen\u00ed tabul\u00e1toru",fullScreen:"P\u0159epnout re\u017eim cel\u00e9 obrazovky",viewSource:"Zobrazit zdroj ve form\u00e1tu HTML",print:"Tisk",newPage:"Nov\u00e1 str\u00e1nka",systemShortcut:'Akce "${0}" je v prohl\u00ed\u017ee\u010di dostupn\u00e1 pouze prost\u0159ednictv\u00edm kl\u00e1vesov\u00e9 zkratky. Pou\u017eijte kl\u00e1vesovou zkratku ${1}.',ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"extra mal\u00e9",2:"velmi mal\u00e9",
3:"mal\u00e9",4:"st\u0159edn\u00ed",5:"velk\u00e9",6:"velmi velk\u00e9",7:"extra velk\u00e9",fontSize:"Velikost",fontName:"P\u00edsmo",formatBlock:"Form\u00e1t",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursive",fantasy:"fantasy",noFormat:"\u017d\u00e1dn\u00fd",p:"Odstavec",h1:"Nadpis",h2:"Podnadpis",h3:"Podnadpis 2",pre:"P\u0159edform\u00e1tovan\u00e9",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"obr\u00e1cen\u00fd vyk\u0159i\u010dn\u00edk",cent:"znak cent",
pound:"znak libra",curren:"znak m\u011bna",yen:"znak yen\nznak yuan",brvbar:"p\u0159eru\u0161en\u00e1 \u010d\u00e1ra\np\u0159eru\u0161en\u00e1 svisl\u00e1 \u010d\u00e1ra",sect:"znak paragraf",uml:"dv\u011b te\u010dky nad\np\u0159ehl\u00e1ska",copy:"znak copyright",ordf:"indik\u00e1tor \u017eensk\u00e9ho rodu",laquo:"dvojit\u00e1 lev\u00e1 \u0161ipka",not:"znak negace",shy:"spojovn\u00edk\nrozd\u011blovn\u00edk",reg:"znak registrov\u00e1no\nznak registrovan\u00e1 ochrann\u00e1 zn\u00e1mka",macr:"macron\nmezerov\u00fd macron\npoml\u010dka nad\npruh naho\u0159e APL",
deg:"znak stupe\u0148",plusmn:"znak plus-minus\nznak plus nebo minus",sup2:"dvojka jako horn\u00ed index\n\u010d\u00edslice dv\u011b jako horn\u00ed index\n\u010dtvere\u010dn\u00ed",sup3:"trojka jako horn\u00ed index\n\u010d\u00edslice t\u0159i jako horn\u00ed index\nkrychlov\u00fd",acute:"\u010d\u00e1rka naho\u0159e",micro:"znak mikro",para:"znak konec odstavce",middot:"te\u010dka uprost\u0159ed\ngeorgi\u00e1nsk\u00e1 \u010d\u00e1rka\n\u0159eck\u00e1 te\u010dka uprost\u0159ed",cedil:"cedilla\noc\u00e1sek vlevo",
sup1:"jedni\u010dka jako horn\u00ed index\n\u010d\u00edslice jedna jako horn\u00ed index",ordm:"indik\u00e1tor mu\u017esk\u00e9ho rodu",raquo:"dvojit\u00e1 prav\u00e1 \u0161ipka",frac14:"jednoduch\u00fd zlomek jedna \u010dtvrtina\nzlomek jedna \u010dtvrtina",frac12:"jednoduch\u00fd zlomek jedna polovina\nzlomek jedna polovina",frac34:"jednoduch\u00fd zlomek t\u0159i \u010dtvrtiny\nzlomek t\u0159i \u010dtvrtiny",iquest:"obr\u00e1cen\u00fd otazn\u00edk\noto\u010den\u00fd otazn\u00edk",Agrave:"velk\u00e9 p\u00edsmeno A s obr\u00e1cenou \u010d\u00e1rkou",
Aacute:"velk\u00e9 p\u00edsmeno A s \u010d\u00e1rkou",Acirc:"velk\u00e9 p\u00edsmeno A se st\u0159\u00ed\u0161kou",Atilde:"velk\u00e9 p\u00edsmeno A s vlnovkou",Auml:"velk\u00e9 p\u00edsmeno A s p\u0159ehl\u00e1skou",Aring:"velk\u00e9 p\u00edsmeno A s krou\u017ekem naho\u0159e",AElig:"velk\u00e9 p\u00edsmeno AE\nslitek AE, velk\u00fd",Ccedil:"velk\u00e9 p\u00edsmeno C se spodn\u00edm h\u00e1\u010dkem",Egrave:"velk\u00e9 p\u00edsmeno E s obr\u00e1cenou \u010d\u00e1rkou",Eacute:"velk\u00e9 p\u00edsmeno E s \u010d\u00e1rkou",
Ecirc:"velk\u00e9 p\u00edsmeno E se st\u0159\u00ed\u0161kou",Euml:"velk\u00e9 p\u00edsmeno E s p\u0159ehl\u00e1skou",Igrave:"velk\u00e9 p\u00edsmeno I s obr\u00e1cenou \u010d\u00e1rkou",Iacute:"velk\u00e9 p\u00edsmeno I s \u010d\u00e1rkou",Icirc:"velk\u00e9 p\u00edsmeno I se st\u0159\u00ed\u0161kou",Iuml:"velk\u00e9 p\u00edsmeno I s p\u0159ehl\u00e1skou",ETH:"velk\u00e9 p\u00edsmeno ETH",Ntilde:"velk\u00e9 p\u00edsmeno N s vlnovkou",Ograve:"velk\u00e9 p\u00edsmeno O s obr\u00e1cenou \u010d\u00e1rkou",
Oacute:"velk\u00e9 p\u00edsmeno O s \u010d\u00e1rkou",Ocirc:"velk\u00e9 p\u00edsmeno O se st\u0159\u00ed\u0161kou",Otilde:"velk\u00e9 p\u00edsmeno O s vlnovkou",Ouml:"velk\u00e9 p\u00edsmeno O s p\u0159ehl\u00e1skou",times:"znak n\u00e1soben\u00ed",Oslash:"velk\u00e9 p\u00edsmeno O s p\u0159e\u0161krtnut\u00edm",Ugrave:"velk\u00e9 p\u00edsmeno U s obr\u00e1cenou \u010d\u00e1rkou",Uacute:"velk\u00e9 p\u00edsmeno U s \u010d\u00e1rkou",Ucirc:"velk\u00e9 p\u00edsmeno U se st\u0159\u00ed\u0161kou",Uuml:"velk\u00e9 p\u00edsmeno U s p\u0159ehl\u00e1skou",
Yacute:"velk\u00e9 p\u00edsmeno Y s \u010d\u00e1rkou",THORN:"velk\u00e9 p\u00edsmeno THORN",szlig:"mal\u00e9 p\u00edsmeno ostr\u00e9 s",agrave:"mal\u00e9 p\u00edsmeno a s obr\u00e1cenou \u010d\u00e1rkou",aacute:"mal\u00e9 p\u00edsmeno a s \u010d\u00e1rkou",acirc:"mal\u00e9 p\u00edsmeno a se st\u0159\u00ed\u0161kou",atilde:"mal\u00e9 p\u00edsmeno a s vlnovkou",auml:"mal\u00e9 p\u00edsmeno a s p\u0159ehl\u00e1skou",aring:"mal\u00e9 p\u00edsmeno a s krou\u017ekem naho\u0159e",aelig:"mal\u00e9 p\u00edsmeno ae\nslitek ae, mal\u00fd",
ccedil:"mal\u00e9 p\u00edsmeno c se spodn\u00edm h\u00e1\u010dkem",egrave:"mal\u00e9 p\u00edsmeno e s obr\u00e1cenou \u010d\u00e1rkou",eacute:"mal\u00e9 p\u00edsmeno e s \u010d\u00e1rkou",ecirc:"mal\u00e9 p\u00edsmeno e se st\u0159\u00ed\u0161kou",euml:"mal\u00e9 p\u00edsmeno e s p\u0159ehl\u00e1skou",igrave:"mal\u00e9 p\u00edsmeno i s obr\u00e1cenou \u010d\u00e1rkou",iacute:"mal\u00e9 p\u00edsmeno i s \u010d\u00e1rkou",icirc:"mal\u00e9 p\u00edsmeno i se st\u0159\u00ed\u0161kou",iuml:"mal\u00e9 p\u00edsmeno i s p\u0159ehl\u00e1skou",
eth:"mal\u00e9 p\u00edsmeno eth",ntilde:"mal\u00e9 p\u00edsmeno n s vlnovkou",ograve:"mal\u00e9 p\u00edsmeno o s obr\u00e1cenou \u010d\u00e1rkou",oacute:"mal\u00e9 p\u00edsmeno o s \u010d\u00e1rkou",ocirc:"mal\u00e9 p\u00edsmeno o se st\u0159\u00ed\u0161kou",otilde:"mal\u00e9 p\u00edsmeno o s vlnovkou",ouml:"mal\u00e9 p\u00edsmeno o s p\u0159ehl\u00e1skou",divide:"znak d\u011blen\u00ed",oslash:"mal\u00e9 p\u00edsmeno o s p\u0159e\u0161krtnut\u00edm",ugrave:"mal\u00e9 p\u00edsmeno u s obr\u00e1cenou \u010d\u00e1rkou",
uacute:"mal\u00e9 p\u00edsmeno u s \u010d\u00e1rkou",ucirc:"mal\u00e9 p\u00edsmeno u se st\u0159\u00ed\u0161kou",uuml:"mal\u00e9 p\u00edsmeno u s p\u0159ehl\u00e1skou",yacute:"mal\u00e9 p\u00edsmeno y s \u010d\u00e1rkou",thorn:"mal\u00e9 p\u00edsmeno thorn",yuml:"mal\u00e9 p\u00edsmeno y s p\u0159ehl\u00e1skou",fnof:"mal\u00e9 p\u00edsmeno f se zahnut\u00fdm h\u00e1\u010dkem\nfunkce\nflorin",Alpha:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno alfa",Beta:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno beta",Gamma:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno gama",
Delta:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno delta",Epsilon:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno epsilon",Zeta:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno z\u00e9ta",Eta:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno \u00e9ta",Theta:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno th\u00e9ta",Iota:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno j\u00f3ta",Kappa:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno kappa",Lambda:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno lambda",Mu:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno m\u00ed",
Nu:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno n\u00fd",Xi:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno ks\u00ed",Omicron:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno omikr\u00f3n",Pi:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno p\u00ed",Rho:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno r\u00f3",Sigma:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno sigma",Tau:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno tau",Upsilon:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno ypsilon",Phi:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno f\u00ed",Chi:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno ch\u00ed",
Psi:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno ps\u00ed",Omega:"velk\u00e9 \u0159eck\u00e9 p\u00edsmeno \u00f3mega",alpha:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno alfa",beta:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno beta",gamma:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno gama",delta:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno delta",epsilon:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno epsilon",zeta:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno z\u00e9ta",eta:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno \u00e9ta",theta:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno th\u00e9ta",
iota:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno j\u00f3ta",kappa:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno kappa",lambda:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno lambda",mu:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno m\u00ed",nu:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno n\u00fd",xi:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno ks\u00ed",omicron:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno omikr\u00f3n",pi:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno p\u00ed",rho:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno r\u00f3",sigmaf:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno koncov\u00e9 sigma",
sigma:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno sigma",tau:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno tau",upsilon:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno ypsilon",phi:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno f\u00ed",chi:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno ch\u00ed",psi:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno ps\u00ed",omega:"mal\u00e9 \u0159eck\u00e9 p\u00edsmeno \u00f3mega",thetasym:"symbol mal\u00e9ho \u0159eck\u00e9ho p\u00edsmena th\u00e9ta",upsih:"symbol \u0159eck\u00e9ho p\u00edsmena ypsilon se zahnut\u00fdm h\u00e1\u010dkem",
piv:"\u0159eck\u00fd symbol p\u00ed",bull:"odr\u00e1\u017eka\nmal\u00fd \u010dern\u00fd krou\u017eek",hellip:"vodorovn\u00e1 v\u00fdpustka\nt\u0159i te\u010dky",prime:"horn\u00ed \u010d\u00e1rka\nminuty\nstopy",Prime:"dvojit\u00e1 horn\u00ed \u010d\u00e1rka\nsekundy\npalce",oline:"\u010d\u00e1ra naho\u0159e\nmezerov\u00e1 \u010d\u00e1ra naho\u0159e",frasl:"lom\u00edtko u zlomk\u016f",weierp:"velk\u00e9 psac\u00ed p\u00edsmeno P\npoten\u010dn\u00ed mno\u017eina\nWeierstrassovo p",image:"velk\u00e9 p\u00edsmeno I, \u0161vabach\nimagin\u00e1rn\u00ed \u010d\u00e1st",
real:"velk\u00e9 p\u00edsmeno R, \u0161vabach\nsymbol re\u00e1ln\u00e9 \u010d\u00e1sti",trade:"znak ochrann\u00e1 zn\u00e1mka",alefsym:"symbol alef\nprvn\u00ed transfinitn\u00ed kardin\u00e1l",larr:"\u0161ipka doleva",uarr:"\u0161ipka nahoru",rarr:"\u0161ipka doprava",darr:"\u0161ipka dol\u016f",harr:"\u0161ipka doleva a doprava",crarr:"\u0161ipka dol\u016f zahnut\u00e1 doleva\nn\u00e1vrat voz\u00edku, konec \u0159\u00e1dku",lArr:"dvojit\u00e1 \u0161ipka doleva",uArr:"dvojit\u00e1 \u0161ipka nahoru",
rArr:"dvojit\u00e1 \u0161ipka doprava",dArr:"dvojit\u00e1 \u0161ipka dol\u016f",hArr:"dvojit\u00e1 \u0161ipka doleva a doprava",forall:"pro v\u0161echny",part:"parci\u00e1ln\u00ed diferenci\u00e1l",exist:"existuje",empty:"pr\u00e1zdn\u00e1 mno\u017eina\nnulov\u00e1 mno\u017eina\npr\u016fm\u011br",nabla:"nabla\nzp\u011btn\u00fd rozd\u00edl",isin:"prvek mno\u017einy",notin:"nen\u00ed prvkem mno\u017einy",ni:"obsahuje jako \u010dlena",prod:"n-\u00e1rn\u00ed sou\u010din\nznak sou\u010dinu",sum:"n-\u00e1rn\u00ed sou\u010det",
minus:"znak minus",lowast:"oper\u00e1tor hv\u011bzdi\u010dka",radic:"druh\u00e1 odmocnina\nznak ko\u0159ene",prop:"\u00fam\u011brn\u00e9",infin:"nekone\u010dno",ang:"\u00fahel",and:"logick\u00e9 a\nkl\u00edn",or:"logick\u00e9 nebo\nv\u00e9",cap:"pr\u016fnik\nuz\u00e1v\u011br",cup:"sjednocen\u00ed\nn\u00e1doba","int":"integr\u00e1l",there4:"a proto",sim:"oper\u00e1tor vlnovka\nli\u0161\u00ed se\npodobn\u00e9",cong:"p\u0159ibli\u017en\u011b rovno",asymp:"t\u00e9m\u011b\u0159 rovno\nasymptotick\u00e9 k",
ne:"nen\u00ed rovno",equiv:"shodn\u00e9 s",le:"men\u0161\u00ed ne\u017e nebo rovno",ge:"v\u011bt\u0161\u00ed ne\u017e nebo rovno",sub:"podmno\u017eina",sup:"nadmno\u017eina",nsub:"nen\u00ed podmno\u017einou",sube:"podmno\u017eina nebo shodn\u00e9 s",supe:"nadmno\u017eina nebo shodn\u00e9 s",oplus:"plus v krou\u017eku\np\u0159\u00edm\u00fd sou\u010det",otimes:"kr\u00e1t v krou\u017eku\nvektorov\u00fd sou\u010din",perp:"sm\u011br nahoru\nv prav\u00e9m \u00fahlu k\nkolm\u00e9",sdot:"oper\u00e1tor te\u010dka",
lceil:"lev\u00e1 horn\u00ed mez",rceil:"prav\u00e1 horn\u00ed cel\u00e1 \u010d\u00e1st",lfloor:"lev\u00e1 doln\u00ed mez",rfloor:"prav\u00e1 doln\u00ed cel\u00e1 \u010d\u00e1st",lang:"lev\u00e1 lomen\u00e1 z\u00e1vorka",rang:"prav\u00e1 lomen\u00e1 z\u00e1vorka",loz:"koso\u010dtverec",spades:"piky",clubs:"k\u0159\u00ed\u017ee\ntrojl\u00edstek",hearts:"srdce\nvalent\u00fdn",diams:"k\u00e1ry",OElig:"slitek OE, velk\u00fd",oelig:"slitek oe, mal\u00fd",Scaron:"velk\u00e9 p\u00edsmeno S s h\u00e1\u010dkem",
scaron:"mal\u00e9 p\u00edsmeno s s h\u00e1\u010dkem",Yuml:"velk\u00e9 p\u00edsmeno Y s p\u0159ehl\u00e1skou",circ:"st\u0159\u00ed\u0161ka, modifik\u00e1tor p\u00edsmen",tilde:"mal\u00e1 vlnovka",ensp:"\u00fazk\u00e1 mezera",emsp:"\u0161irok\u00e1 mezera",thinsp:"z\u00fa\u017een\u00e1 mezera",zwnj:"z\u00e1kaz spojen\u00ed, nulov\u00e1 \u0161\u00ed\u0159ka",zwj:"spojen\u00ed, nulov\u00e1 \u0161\u00ed\u0159ka",lrm:"zna\u010dka sm\u011bru zleva doprava",rlm:"zna\u010dka sm\u011bru zprava doleva",ndash:"kr\u00e1tk\u00e1 poml\u010dka",
mdash:"dlouh\u00e1 poml\u010dka",lsquo:"lev\u00fd apostrof",rsquo:"prav\u00fd apostrof",sbquo:"doln\u00ed apostrof",ldquo:"lev\u00e9 uvozovky",rdquo:"prav\u00e9 uvozovky",bdquo:"doln\u00ed uvozovky",dagger:"k\u0159\u00ed\u017eek",Dagger:"dvojit\u00fd k\u0159\u00ed\u017eek",permil:"znak promile",lsaquo:"lev\u00e1 \u0161ipka",rsaquo:"prav\u00e1 \u0161ipka",euro:"znak euro",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Vlo\u017eit symbol",_localized:{}},"dojo/nls/colors":{aliceblue:"modrav\u00e1",
antiquewhite:"kr\u00e9mov\u011b b\u00edl\u00e1",aqua:"azurov\u00e1",aquamarine:"akvamar\u00ednov\u00e1",azure:"bled\u011b azurov\u00e1",beige:"bled\u011b b\u00e9\u017eov\u00e1",bisque:"bled\u011b oran\u017eov\u00e1",black:"\u010dern\u00e1",blanchedalmond:"mandlov\u00e1",blue:"modr\u00e1",blueviolet:"modrofialov\u00e1",brown:"\u010dervenohn\u011bd\u00e1",burlywood:"kr\u00e9mov\u00e1",cadetblue:"\u0161edomodr\u00e1",chartreuse:"chartreuska",chocolate:"hn\u011bdob\u00e9\u017eov\u00e1",coral:"kor\u00e1lov\u00e1 \u010derven\u00e1",
cornflowerblue:"chrpov\u011b modr\u00e1",cornsilk:"re\u017en\u00e1",crimson:"karm\u00ednov\u00e1",cyan:"azurov\u00e1",darkblue:"tmav\u011b modr\u00e1",darkcyan:"tmav\u011b azurov\u00e1",darkgoldenrod:"tmav\u011b b\u00e9\u017eov\u00e1",darkgray:"tmav\u011b \u0161ed\u00e1",darkgreen:"tmav\u011b zelen\u00e1",darkgrey:"tmav\u011b \u0161ed\u00e1",darkkhaki:"p\u00edskov\u011b hn\u011bd\u00e1",darkmagenta:"tmav\u011b purpurov\u00e1",darkolivegreen:"tmav\u011b olivov\u00e1",darkorange:"tmav\u011b oran\u017eov\u00e1",
darkorchid:"tmav\u011b orchidejov\u00e1",darkred:"tmav\u011b \u010derven\u00e1",darksalmon:"tmav\u011b lososov\u00e1",darkseagreen:"tmav\u00e1 mo\u0159sk\u00e1 zelen\u00e1",darkslateblue:"tmav\u00e1 b\u0159idlicov\u00e1 modr\u00e1",darkslategray:"tmav\u00e1 b\u0159idlicov\u00e1 \u0161ed\u00e1",darkslategrey:"tmav\u00e1 b\u0159idlicov\u00e1 \u0161ed\u00e1",darkturquoise:"tmav\u011b tyrkysov\u00e1",darkviolet:"tmav\u011b fialov\u00e1",deeppink:"syt\u011b r\u016f\u017eov\u00e1",deepskyblue:"syt\u00e1 nebesk\u00e1 modr\u00e1",
dimgray:"kou\u0159ov\u011b \u0161ed\u00e1",dimgrey:"kou\u0159ov\u011b \u0161ed\u00e1",dodgerblue:"jasn\u011b modr\u00e1",firebrick:"cihlov\u00e1",floralwhite:"kv\u011btinov\u011b b\u00edl\u00e1",forestgreen:"lesn\u00ed zelen\u00e1",fuchsia:"fuchsiov\u00e1",gainsboro:"bled\u011b \u0161ed\u00e1",ghostwhite:"modrav\u011b b\u00edl\u00e1",gold:"zlat\u00e1",goldenrod:"b\u00e9\u017eov\u00e1",gray:"\u0161ed\u00e1",green:"zelen\u00e1",greenyellow:"zeleno\u017elut\u00e1",grey:"\u0161ed\u00e1",honeydew:"nazelenal\u00e1",
hotpink:"jasn\u011b r\u016f\u017eov\u00e1",indianred:"indi\u00e1nsk\u00e1 \u010derven\u00e1",indigo:"indigov\u011b modr\u00e1",ivory:"slonovinov\u00e1",khaki:"p\u00edskov\u00e1",lavender:"levandulov\u00e1",lavenderblush:"levandulov\u00e1 r\u016f\u017eov\u00e1",lawngreen:"jasn\u011b zelen\u00e1",lemonchiffon:"sv\u011btle citr\u00f3nov\u00e1",lightblue:"sv\u011btle modr\u00e1",lightcoral:"sv\u011btle kor\u00e1lov\u00e1",lightcyan:"sv\u011btle azurov\u00e1",lightgoldenrodyellow:"sv\u011btle \u017elut\u00e1",
lightgray:"sv\u011btle \u0161ed\u00e1",lightgreen:"sv\u011btle zelen\u00e1",lightgrey:"sv\u011btle \u0161ed\u00e1",lightpink:"sv\u011btle r\u016f\u017eov\u00e1",lightsalmon:"sv\u011btle lososov\u00e1",lightseagreen:"sv\u011btl\u00e1 mo\u0159sk\u00e1 zelen\u00e1",lightskyblue:"sv\u011btl\u00e1 nebesk\u00e1 modr\u00e1",lightslategray:"sv\u011btl\u00e1 b\u0159idlicov\u00e1 \u0161ed\u00e1",lightslategrey:"sv\u011btl\u00e1 b\u0159idlicov\u00e1 \u0161ed\u00e1",lightsteelblue:"sv\u011btl\u00e1 ocelov\u00e1 modr\u00e1",
lightyellow:"bled\u011b \u017elut\u00e1",lime:"limetkov\u00e1",limegreen:"limetkov\u011b zelen\u00e1",linen:"bled\u011b \u0161edob\u00e9\u017eov\u00e1",magenta:"purpurov\u00e1",maroon:"ka\u0161tanov\u00e1",mediumaquamarine:"st\u0159edn\u00ed akvamar\u00ednov\u00e1",mediumblue:"st\u0159edn\u011b modr\u00e1",mediumorchid:"st\u0159edn\u011b orchidejov\u00e1",mediumpurple:"st\u0159edn\u011b nachov\u00e1",mediumseagreen:"st\u0159edn\u00ed mo\u0159sk\u00e1 zelen\u00e1",mediumslateblue:"st\u0159edn\u00ed b\u0159idlicov\u00e1 modr\u00e1",
mediumspringgreen:"st\u0159edn\u00ed jarn\u00ed zelen\u00e1",mediumturquoise:"st\u0159edn\u011b tyrkysov\u00e1",mediumvioletred:"st\u0159edn\u011b fialovo\u010derven\u00e1",midnightblue:"temn\u011b modr\u00e1",mintcream:"mentolov\u00e1",mistyrose:"r\u016f\u017eovob\u00edl\u00e1",moccasin:"bled\u011b kr\u00e9mov\u00e1",navajowhite:"sv\u011btle kr\u00e9mov\u00e1",navy:"n\u00e1mo\u0159nick\u00e1 modr\u00e1",oldlace:"sv\u011btle b\u00e9\u017eov\u00e1",olive:"olivov\u00e1",olivedrab:"khaki",orange:"oran\u017eov\u00e1",
orangered:"oran\u017eovo\u010derven\u00e1",orchid:"orchidejov\u00e1",palegoldenrod:"bled\u011b p\u00edskov\u00e1",palegreen:"bled\u011b zelen\u00e1",paleturquoise:"bled\u011b tyrkysov\u00e1",palevioletred:"bled\u011b fialovo\u010derven\u00e1",papayawhip:"pap\u00e1jov\u00e1",peachpuff:"broskvov\u00e1",peru:"karamelov\u00e1",pink:"r\u016f\u017eov\u00e1",plum:"\u0161vestkov\u00e1",powderblue:"bled\u011b modr\u00e1",purple:"nachov\u00e1",red:"\u010derven\u00e1",rosybrown:"r\u016f\u017eovohn\u011bd\u00e1",
royalblue:"kr\u00e1lovsk\u00e1 modr\u00e1",saddlebrown:"hn\u011bd\u00e1",salmon:"lososov\u00e1",sandybrown:"oran\u017eovohn\u011bd\u00e1",seagreen:"mo\u0159sk\u00e1 zelen\u00e1",seashell:"lasturov\u00e1",sienna:"siena",silver:"st\u0159\u00edbrn\u00e1",skyblue:"nebesk\u00e1 modr\u00e1",slateblue:"b\u0159idlicov\u00e1 modr\u00e1",slategray:"b\u0159idlicov\u00e1 \u0161ed\u00e1",slategrey:"b\u0159idlicov\u00e1 \u0161ed\u00e1",snow:"sn\u011bhob\u00edl\u00e1",springgreen:"jarn\u00ed zelen\u00e1",steelblue:"ocelov\u00e1 modr\u00e1",
tan:"\u0161edob\u00e9\u017eov\u00e1",teal:"\u0161edozelen\u00e1",thistle:"bodl\u00e1kov\u00e1",tomato:"tomatov\u00e1",transparent:"pr\u016fhledn\u00e1",turquoise:"tyrkysov\u00e1",violet:"fialov\u00e1",wheat:"zlatohn\u011bd\u00e1",white:"b\u00edl\u00e1",whitesmoke:"kou\u0159ov\u011b b\u00edl\u00e1",yellow:"\u017elut\u00e1",yellowgreen:"\u017elutozelen\u00e1",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"\u010d",greenLabel:"z",blueLabel:"m",hueLabel:"o",saturationLabel:"n",valueLabel:"j",
degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"Selektor odst\u00ednu",saturationPickerTitle:"Selektor sytosti",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Vlo\u017eit tabulku",modifyTableTitle:"Upravit tabulku",rows:"\u0158\u00e1dky:",columns:"Sloupce:",align:"Zarovnat:",cellPadding:"Okraj bu\u0148ky:",cellSpacing:"Odstup bun\u011bk:",tableWidth:"\u0160\u00ed\u0159ka tabulky:",backgroundColor:"Barva pozad\u00ed:",borderColor:"Barva ohrani\u010den\u00ed:",borderThickness:"Tlou\u0161\u0165ka ohrani\u010den\u00ed:",
percent:"procent",pixels:"pixel\u016f","default":"v\u00fdchoz\u00ed",left:"vlevo",center:"st\u0159ed",right:"vpravo",buttonSet:"Nastavit",buttonInsert:"Vlo\u017eit",buttonCancel:"Storno",selectTableLabel:"Vybrat tabulku",insertTableRowBeforeLabel:"P\u0159idat \u0159\u00e1dek p\u0159ed",insertTableRowAfterLabel:"P\u0159idat \u0159\u00e1dek za",insertTableColumnBeforeLabel:"P\u0159idat sloupec p\u0159ed",insertTableColumnAfterLabel:"P\u0159idat sloupec za",deleteTableRowLabel:"Odstranit \u0159\u00e1dek",
deleteTableColumnLabel:"Odstranit sloupec",colorTableCellTitle:"Bu\u0148ka tabulky barev pozad\u00ed",tableContextMenuTitle:"Kontextov\u00e1 nab\u00eddka tabulky",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Vlo\u017eit z aplikace Word",instructions:"Vlo\u017ete obsah z aplikace Word do zobrazen\u00e9ho textov\u00e9ho pole. Jakmile jste s vkl\u00e1dan\u00fdm obsahem spokojeni, stiskn\u011bte tla\u010d\u00edtko Vlo\u017eit. Pomoc\u00ed tla\u010d\u00edtka Storno vkl\u00e1d\u00e1n\u00ed zru\u0161\u00edte.",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Vlo\u017eit kotvu",title:"Vlastnosti kotvy",anchor:"N\u00e1zev:",text:"Popis:",set:"Nastavit",cancel:"Storno",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Citace v bloku",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Vlo\u017eit obr\u00e1zek",url:"Obr\u00e1zek",browse:"Proch\u00e1zet...",text:"Popis",set:"Vlo\u017eit",invalidMessage:"Neplatn\u00fd typ souboru obr\u00e1zku",prePopuTextUrl:"Zadejte adresu URL obr\u00e1zku",
prePopuTextBrowse:" nebo vyhledejte lok\u00e1ln\u00ed soubor.",_localized:{}},"dojo/cldr/nls/gregorian":{"dateFormatItem-Ehm":"E h:mm a","days-standAlone-short":"ne po \u00fat st \u010dt p\u00e1 so".split(" "),"months-format-narrow":"1 2 3 4 5 6 7 8 9 10 11 12".split(" "),"field-second-relative+0":"nyn\u00ed","quarters-standAlone-narrow":["1","2","3","4"],"field-weekday":"Den v t\u00fddnu","dateFormatItem-yQQQ":"QQQ y","dateFormatItem-yMEd":"E d. M. y","field-wed-relative+0":"tuto st\u0159edu","field-wed-relative+1":"p\u0159\u00ed\u0161t\u00ed st\u0159edu",
"dateFormatItem-GyMMMEd":"E d. M. y G","dateFormatItem-MMMEd":"E d. M.",eraNarrow:["p\u0159.n.l.","n.l."],"field-tue-relative+-1":"minul\u00e9 \u00fater\u00fd","days-format-short":"ne po \u00fat st \u010dt p\u00e1 so".split(" "),"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormat-long":"d. MMMM y","field-fri-relative+-1":"minul\u00fd p\u00e1tek","field-wed-relative+-1":"minulou st\u0159edu","months-format-wide":"ledna \u00fanora b\u0159ezna dubna kv\u011btna \u010dervna \u010dervence srpna z\u00e1\u0159\u00ed \u0159\u00edjna listopadu prosince".split(" "),
"dateTimeFormat-medium":"{1} {0}","dayPeriods-format-wide-pm":"PM","dateFormat-full":"EEEE d. MMMM y","field-thu-relative+-1":"minul\u00fd \u010dtvrtek","dateFormatItem-Md":"d. M.","dayPeriods-format-abbr-am":"AM","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dayPeriods-format-wide-noon":"noon","dateFormatItem-yMd":"d. M. y","field-era":"Letopo\u010det","dateFormatItem-yM":"M/y","months-standAlone-wide":"leden \u00fanor b\u0159ezen duben kv\u011bten \u010derven \u010dervenec srpen z\u00e1\u0159\u00ed \u0159\u00edjen listopad prosinec".split(" "),
"timeFormat-short":"H:mm","quarters-format-wide":["1. \u010dtvrtlet\u00ed","2. \u010dtvrtlet\u00ed","3. \u010dtvrtlet\u00ed","4. \u010dtvrtlet\u00ed"],"dateFormatItem-yQQQQ":"QQQQ y","timeFormat-long":"H:mm:ss z","field-year":"Rok","dateFormatItem-yMMM":"LLLL y","dateTimeFormats-appendItem-Era":"{1} {0}","field-hour":"Hodina","months-format-abbr":"led \u00fano b\u0159e dub kv\u011b \u010dvn \u010dvc srp z\u00e1\u0159 \u0159\u00edj lis pro".split(" "),"field-sat-relative+0":"tuto sobotu","field-sat-relative+1":"p\u0159\u00ed\u0161t\u00ed sobotu",
"timeFormat-full":"H:mm:ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","field-day-relative+0":"dnes","field-thu-relative+0":"tento \u010dtvrtek","field-day-relative+1":"z\u00edtra","field-thu-relative+1":"p\u0159\u00ed\u0161t\u00ed \u010dtvrtek","dateFormatItem-GyMMMd":"d. M. y G","dateFormatItem-H":"H","months-standAlone-abbr":"led \u00fano b\u0159e dub kv\u011b \u010dvn \u010dvc srp z\u00e1\u0159 \u0159\u00edj lis pro".split(" "),"quarters-format-abbr":["Q1","Q2","Q3","Q4"],"quarters-standAlone-wide":["1. \u010dtvrtlet\u00ed",
"2. \u010dtvrtlet\u00ed","3. \u010dtvrtlet\u00ed","4. \u010dtvrtlet\u00ed"],"dateFormatItem-Gy":"y G","dateFormatItem-M":"L","days-standAlone-wide":"ned\u011ble pond\u011bl\u00ed \u00fater\u00fd st\u0159eda \u010dtvrtek p\u00e1tek sobota".split(" "),"dayPeriods-format-abbr-noon":"noon","timeFormat-medium":"H:mm:ss","field-sun-relative+0":"tuto ned\u011bli","dateFormatItem-Hm":"H:mm","field-sun-relative+1":"p\u0159\u00ed\u0161t\u00ed ned\u011bli","quarters-standAlone-abbr":["Q1","Q2","Q3","Q4"],eraAbbr:["p\u0159. n. l.",
"n. l."],"field-minute":"Minuta","field-dayperiod":"AM/PM","days-standAlone-abbr":"ne po \u00fat st \u010dt p\u00e1 so".split(" "),"dateFormatItem-d":"d.","dateFormatItem-ms":"mm:ss","quarters-format-narrow":["1","2","3","4"],"field-day-relative+-1":"v\u010dera","dateTimeFormat-long":"{1} {0}","dayPeriods-format-narrow-am":"AM","dateFormatItem-h":"h a","dateFormatItem-MMMd":"d. M.","dateFormatItem-MEd":"E d. M.","dateTimeFormat-full":"{1} {0}","field-fri-relative+0":"tento p\u00e1tek","field-fri-relative+1":"p\u0159\u00ed\u0161t\u00ed p\u00e1tek",
"field-day":"Den","days-format-wide":"ned\u011ble pond\u011bl\u00ed \u00fater\u00fd st\u0159eda \u010dtvrtek p\u00e1tek sobota".split(" "),"field-zone":"\u010casov\u00e9 p\u00e1smo","months-standAlone-narrow":"l\u00fabdk\u010d\u010dsz\u0159lp".split(""),"dateFormatItem-y":"y","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","field-year-relative+-1":"minul\u00fd rok","field-month-relative+-1":"minul\u00fd m\u011bs\u00edc","dateTimeFormats-appendItem-Year":"{1} {0}","dateFormatItem-hm":"h:mm a","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})",
"dayPeriods-format-abbr-pm":"PM","days-format-abbr":"ne po \u00fat st \u010dt p\u00e1 so".split(" "),eraNames:["p\u0159. n. l.","n. l."],"dateFormatItem-yMMMd":"d. M. y","days-format-narrow":"NP\u00daS\u010cPS".split(""),"field-month":"M\u011bs\u00edc","days-standAlone-narrow":"NP\u00daS\u010cPS".split(""),"dateFormatItem-MMM":"LLL","field-tue-relative+0":"toto \u00fater\u00fd","dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","field-tue-relative+1":"p\u0159\u00ed\u0161t\u00ed \u00fater\u00fd",
"dayPeriods-format-wide-am":"AM","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormatItem-EHm":"E H:mm","field-mon-relative+0":"toto pond\u011bl\u00ed","field-mon-relative+1":"p\u0159\u00ed\u0161t\u00ed pond\u011bl\u00ed","dateFormat-short":"dd.MM.yy","dateFormatItem-EHms":"E H:mm:ss","dateFormatItem-Ehms":"E h:mm:ss a","dayPeriods-format-narrow-noon":"n","field-second":"Sekunda","field-sat-relative+-1":"minulou sobotu","dateFormatItem-yMMMEd":"E d. M. y",
"field-sun-relative+-1":"minulou ned\u011bli","field-month-relative+0":"tento m\u011bs\u00edc","field-month-relative+1":"p\u0159\u00ed\u0161t\u00ed m\u011bs\u00edc","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateFormatItem-Ed":"E d.","field-week":"T\u00fdden","dateFormat-medium":"d. M. y","field-week-relative+-1":"minul\u00fd t\u00fdden","field-year-relative+0":"tento rok","field-year-relative+1":"p\u0159\u00ed\u0161t\u00ed rok","dayPeriods-format-narrow-pm":"PM","dateTimeFormat-short":"{1} {0}",
"dateFormatItem-Hms":"H:mm:ss","dateFormatItem-hms":"h:mm:ss a","dateFormatItem-GyMMM":"LLLL y G","field-mon-relative+-1":"minul\u00e9 pond\u011bl\u00ed","field-week-relative+0":"tento t\u00fdden","field-week-relative+1":"p\u0159\u00ed\u0161t\u00ed t\u00fdden","dateFormatItem-yMMMMd":"d. MMMM y","field-day-relative+2":"poz\u00edt\u0159\u00ed","dateFormatItem-MMMMd":"d. MMMM","dateFormatItem-GyMMMMd":"d. MMMM y G","field-day-relative+-2":"p\u0159edev\u010d\u00edrem","dateFormatItem-yMMMM":"LLLL y",
"dateFormatItem-MMMMEd":"E d. MMMM","dateFormatItem-yMMMMEd":"E d. MMMM y","dateFormatItem-GyMMMMEd":"E d. MMMM y G",_localized:{}}});
//# sourceMappingURL=dojo_cs.js.map